---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: tillsteinbach

---

**Describe the bug**
A clear and concise description of what the bug is.

IMPORTANT! CarConnectivity consists of several modules, try to check what module could be the source of the problem and post the issue there.

Examples:
- If you have a problem getting data from your car, it is likely the connector. Please open the bug in the connector repository
- If you have a problem with the webinterface post the bug in the webui-plugin repository
- If you have a problem with MQTT, post the bug in the mqtt-plugin repository

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Logs**
IF applicable logs that show the problem. Please take care to remove any confidential data from the logs (e.g. your vehicles VIN number, usernames or passwords)

 - OS: [e.g. Windows, Linux, MacOS, ...]
 - Version used [e.g. 0.6.2]

**Additional context**
Add any other context about the problem here.
